/***************************************************************************
 * globals.h  -  global header
 *
 * Copyright (C) 2003 - 2009 Florian Richter
 ***************************************************************************/
/*
   This program is free software; you can redistribute it and/or modify
   it under the terms of the GNU General Public License as published by
   the Free Software Foundation; either version 3 of the License, or
   (at your option) any later version.
   
   You should have received a copy of the GNU General Public License
   along with this program.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef SMC_GLOBALS_H
#define SMC_GLOBALS_H

/* *** *** *** *** *** *** *** global headers *** *** *** *** *** *** *** *** *** *** */

#include "global_basic.h"
#include "global_game.h"

/* *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** *** */

#endif
